@@ -200,7 +200,7 @@ void handle_key (XKeyEvent *key_event, bool pressed)
         case XK_Z :           KEY(1,1,5); break;
         default :
             keycode = 0xFFFF;
-            printf ("Received unhandled key %x\n", keysym);
+            printf ("Received unhandled key %x\n", (int)keysym);
             break;
     }
 
@@ -222,6 +222,8 @@ void handle_key (XKeyEvent *key_event, bool pressed)
                      | (  (keys_pressed ? shifted_keys : shift)
                         ? 0 : 0x80)
                      | (control ? 0 : 0x40);
+    memory[ 0xb002 ] = (memory[ 0xb002 ] & 0xbf)
+                     | (alt ? 0 : 0x40 );
 #ifdef DEBUG
     {   int i;
         printf("%04x r:%d p:%d s:%d %02x->%02x  ", keysym, 
